@@ -303,9 +303,6 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
         logs.系统日志("验证密码", PI)
         password_res = [f"{id_protect}"] + [f"{password_a}"]
         logs.系统日志(f"Fishconsole》passwordsys》password_res is {password_res}", PI)
-        if password_res is None:
-            print(logs.颜色(logs.日志("用户取消了操作"), 色选="红色"))
-            exit()
         p_res = ""
         t_res = ""
         for a in password_res[0]:
@@ -492,8 +489,6 @@ def 密码(模式, 原文, 密码: str = ""):
         b = passwordsys(1, a, 密码)
         logs.系统日志(f"b is {b}", PI)
         return b
-    elif not 模式:
-        return 原文
     else:
         c = passwordsys(2, 密码, 原文)
         logs.系统日志(f"c is {c}", PI)
@@ -612,10 +607,41 @@ def 字符转unicode(模式, 原文: str):
         logs.系统日志(f"》Fishconsole》字符串转unicode》type e is {type(e)}", ZUI)
         logs.系统日志(f"》Fishconsole》字符串转unicode》e is {e}", ZUI)
         return e
-
-
     else:
         logs.错误跟踪(["Fishconsole", "字符串转unicode", "模式"], "请选择正确的模式", {模式})
+
+
+
+
+
+
+def 强制类型检测(任意变量,预期类型):
+    type值=str(type(任意变量))
+    变量类型=type值.split("'")[1]
+    if 变量类型==预期类型:
+        return True
+    else:
+        return False
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 # 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
@@ -638,7 +664,6 @@ if sys:
         # +以在下一次检测到版本还是低的话继续保持未检测的状态，如果成功了，那就将False修改为ture，这个fupadta是独立的
 
         # 而updata是helps.帮助弄过来的，它的用处就是让tool执行强制更新的操作
-
         # 因为没有文件，所以我们在一开始就要创建文件，这个创建文件有一个规则，就是需要创建啥就写入啥，不要一股脑全写，因为这样就显得不高效
         config = {"updata": True, "fup": False}
         logs.系统日志("强制更新系统》首次运行，添加fup到缓存", UPI)
