@@ -355,7 +355,8 @@ def 帮助():
                         "排名模块",
                         "文件存在性检测模块",
                         "缓存模块",
-                        "文本转Unicode模块"
+                        "文本转Unicode模块",
+                        "强制类型检测"
                     ])
                     logs.系统日志(f"用户请求启动{res}")
                     if res == None:
@@ -415,3 +416,12 @@ def 帮助():
                                 "Fishsys.文本转Unicode(模式，原文)\n"
                                 "模式有两种，模式1：为文本转unicode\n模式2：为str类型的unicode转文字\n"
                                 , "文本转unicode", "ok")
+                        if a == "强制类型检测":
+                            window.弹窗(
+                                "这个东西的用处还是挺多的，就是在防止乱给参数的情况"
+                                "\n-----------------------------\n\n"
+                                "语法就是\n"
+                                "Fishsys.强制类型检测(任意变量，预期类型)\n"
+                                "如果传入的变量类型符合预期的变量类型，就返回Ture，否则返回False。\n\n"
+                                "其实也就那样了\n"
+                                , "强制类型检测", "ok")
